code stringlengths 2 1.05M | repo_name stringlengths 5 101 | path stringlengths 4 991 | language stringclasses 3
values | license stringclasses 5
values | size int64 2 1.05M |
|---|---|---|---|---|---|
<#
.NOTES
Author: @jhowardmsft
Summary: Windows native build script. This is similar to functionality provided
by hack\make.sh, but uses native Windows PowerShell semantics. It does
not support the full set of options provided by the Linux counterpart.
For example:
... | yongtang/docker | hack/make.ps1 | PowerShell | apache-2.0 | 21,832 |
#
# Module manifest for module 'Microsoft.Azure.Commands.OperationalInsights'
#
# Generated by: Microsoft Corporation
#
# Generated on: 05/28/2015
#
@{
# Version number of this module.
ModuleVersion = '0.9.10'
# ID used to uniquely identify this module
GUID = '5BE35A94-C20F-4659-AA29-9B9AEBCFAF36'
# Author of this... | devigned/azure-powershell | src/ResourceManager/OperationalInsights/Commands.OperationalInsights/Microsoft.Azure.Commands.OperationalInsights.dll-Help.psd1 | PowerShell | apache-2.0 | 3,101 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | AzureAutomationTeam/azure-powershell | src/StackAdmin/Azs.KeyVault.Admin/Tests/src/Common.ps1 | PowerShell | apache-2.0 | 1,221 |
$thisScriptFolder = (Split-Path -parent $MyInvocation.MyCommand.Definition)
$chocInstallVariableName = "ChocolateyInstall"
$sysDrive = $env:SystemDrive
$tempDir = $env:TEMP
$defaultChocolateyPathOld = "$sysDrive\Chocolatey"
#$ErrorActionPreference = 'Stop'
$debugModeParams = $null
function Initialize-Chocolate... | ewilde/choco | nuget/chocolatey/tools/chocolateysetup.psm1 | PowerShell | apache-2.0 | 20,536 |
<#
Modules NEEDED FOR this script - * AzureRM * AzureAD * AzureDiagnosticsAndLogAnalytics * SqlServer * Enable-AzureRMDiagnostics (Script)
Note: This script requires you to run script in an elevated mode i.e -Run As Administrator-
This script imports and Install required powershell modules and creates Glo... | AvyanConsultingCorp/pci-paas-webapp-ase-sqldb-appgateway-keyvault-oms | 0-Setup-AdministrativeAccountAndPermission.ps1 | PowerShell | mit | 16,621 |
Configuration Assert_AppInstall
{
param
(
[Parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[String] $InstallationPackage,
[Parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[String] $PackageVersion
)
Import-DscResource –ModuleName P... | lgramatikov/kelleadsc | DSC/Assert_AppInstall.ps1 | PowerShell | mit | 12,108 |
import-module au
function global:au_SearchReplace {
@{
".\tools\chocolateyInstall.ps1" = @{
"(?i)(^\s*packageName\s*=\s*)('.*')" = "`$1'$($Latest.PackageName)'"
}
".\legal\VERIFICATION.txt" = @{
"(?i)(\s+x32:).*" = "`${1} $($Latest.URL32)"
"(?i... | sippi90/chocolateyautomaticpackages | setuserfta/update.ps1 | PowerShell | mit | 1,439 |
Function Get-EventLogSpan {
<#
.SYNOPSIS
Function for veryfing Windows events log span - how old is the oldest available log event entry
.DESCRIPTION
Function for veryfing Windows events log span - how old is the oldest available log event entry
As a result for this function you receive ra... | it-praktyk/Get-EventLogSpan | Get-EventLogSpan.ps1 | PowerShell | mit | 14,501 |
<#
.SYNOPSIS
Sets the Sitecore user properties.
.DESCRIPTION
The Set-User command sets a user profile properties in Sitecore.
The Identity parameter specifies the Sitecore user to set. You can specify a user by its local name or fully qualified name.
.PARAMETER Identity
Sp... | ostat/Console | Documentation/Set-User.ps1 | PowerShell | mit | 2,412 |
$path = 'c:\Program Files\WindowsPowershell\Modules\Cidney\'
#$path = 'c:\Projects\Cidney\'
Import-module (Join-path $path 'Cidney.psd1')
pipeline: CidneyBuild {
$base = (Get-Module Cidney).ModuleBase
Import-Module Pester
Stage: Pester {
Do: { Invoke-Pester -Script "$base\Tests\Pipeline.Test... | Cidney/Cidney | Tests/TestCidney.ps1 | PowerShell | mit | 637 |
#region Track WS Memory -- RUN THIS PORTION IN CONSOLE!
$Script:PeakMemory = 0
$RegExPattern = (Get-Process powershell).ID -join '|'
While ($True) {
Clear-Host
$Data = Get-Process -Name powershell | Where ID -notmatch "$RegExPattern" | #Other PID should be from other console
Select @{L='WS(MB)';E={"{0:N}" ... | proxb/Presentations | Art_Of_PowerShell_Runspaces/4_1_2_RunspacesDemo_PSJobPerf.ps1 | PowerShell | mit | 1,469 |
$PackageName = '{{PackageName}}'
# Per-package parameters
$downloadUrl = '{{DownloadURL}}'
$md5Checksum = '{{MD5Checksum}}'
$neozipSubdir = '{{NeoZipSubdir}}'
# major.minor.update.build
# Build is always 14
$privateJavaVersion = "{{PrivateJavaVersion}}"
$privateJreChecksumMD5 = "{{PrivateJreChecksumMD5}}"
# START Help... | glennsarti/neo4j-community-chocolatey | templates/neo4j-community-v3.1/tools/chocolateyInstall.ps1 | PowerShell | mit | 11,940 |
#
# Based on the great work by Posh-git!
#
# Vagrant status is slower then is resonable for a prompt to render. I am making some assumptions
# by scraping the .vagrant folder for any id files that should represent active/aborted some sort
# of Vagrant machine activity.
#
#
function Get-VagrantFile {
$fileN... | muteldar/posh-git-vagrant-status | VagrantUtils.ps1 | PowerShell | mit | 4,591 |
$ErrorActionPreference = "Stop"
$CONFIG = "install.conf.yaml"
$DOTBOT_DIR = "dotbot"
$DOTBOT_BIN = "bin/dotbot"
$BASEDIR = $PSScriptRoot
Set-Location $BASEDIR
Set-Location $DOTBOT_DIR && git submodule update --init --recursive
foreach ($PYTHON in ('python', 'python3', 'python2')) {
# Python redirects to Microso... | anishathalye/dotbot | tools/hg-subrepo/install.ps1 | PowerShell | mit | 709 |
# Copyright (c) Microsoft Corporation. All rights reserved.
$InitialDatabase = '0'
$knownExceptions = @(
'System.Data.Entity.Migrations.Infrastructure.MigrationsException',
'System.Data.Entity.Migrations.Infrastructure.AutomaticMigrationsDisabledException',
'System.Data.Entity.Migrations.Infrastructure.A... | msmgxe/upc_tp3-adm | packages/EntityFramework.6.2.0-beta1/tools/EntityFramework.psm1 | PowerShell | mit | 43,621 |
<#
The below statement stays in for every test you build.
#>
$CommandName = $MyInvocation.MyCommand.Name.Replace(".Tests.ps1", "")
Write-Host -Object "Running $PSCommandPath" -ForegroundColor Cyan
. "$PSScriptRoot\constants.ps1"
<#
Unit test is required for any command added
#>
Describe "$CommandName Unit Test... | dsolodow/dbatools | tests/Test-DbaManagementObject.Tests.ps1 | PowerShell | mit | 1,814 |
#
# Copyright 2018 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agre... | GoogleCloudPlatform/citrix-on-gcp | bootstrap/ctx-cloud-connector.ps1 | PowerShell | apache-2.0 | 7,213 |
#
# Module manifest for module 'PSGet_Azure'
#
# Generated by: Microsoft Corporation
#
# Generated on: 10/31/2016
#
@{
# Script module or binary module file associated with this manifest.
# RootModule = ''
# Version number of this module.
ModuleVersion = '3.3.0'
# Supported PSEditions
# CompatiblePSEditions = @()
... | alfantp/azure-powershell | src/ServiceManagement/Services/Commands.Utilities/Azure.psd1 | PowerShell | apache-2.0 | 35,909 |
<#
Copyright 2016 ASOS.com Limited
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, softwar... | paulmarsy/OctopusStepTemplateCi | OctopusStepTemplateCi/Cmdlets/Internal/Octopus/StepTemplates/Compare-Hashtable.Tests.ps1 | PowerShell | apache-2.0 | 2,066 |
# This contains a few different samples, you can manually invoke these in PS ISE.
# This script shouldn't be invoked directly
exit
# CD to the project directory before invoking the funcitons below
# Set-Alias msbuild ('{0}\MSBuild\12.0\bin\amd64\msbuild.exe' -f ${env:ProgramFiles(x86)})
# How to use a publish pro... | sayedihashimi/netconf2014 | samples/CustomParams/AzureJobs.SiteExtension.Web/samples.ps1 | PowerShell | apache-2.0 | 668 |
# Copyright © 2011 - Present RealDimensions Software, LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
#
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by ap... | Apteryx0/choco | GenerateDocs.ps1 | PowerShell | apache-2.0 | 19,820 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | yoavrubin/azure-powershell | src/ResourceManager/HDInsight/Commands.HDInsight.Test/ScenarioTests/DataLakeStoreScenarioTests.ps1 | PowerShell | apache-2.0 | 2,289 |
<#
.Synopsis
This module will query Active Directory for the hostname, OS version, and service pack level
for each computer account. That information is then cross-referenced against a list of common
Metasploit exploits that can be used during penetration testing.
.DESCRIPTION
This module will que... | Yas3r/Empire | data/module_source/situational_awareness/network/Get-ExploitableSystems.psm1 | PowerShell | bsd-3-clause | 24,254 |
<#
.SYNOPSIS
NIC Advanced Properties
.DESCRIPTION
Configure NIC Advanced Properties by modifying the values in the HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Class\{4d36e972-e325-11ce-bfc1-08002be10318} registry key.
.PARAMETER ConsoleTitle
Title displayed in the PowerShell Console
.P... | MicksITBlogs/PowerShell | NICAdvancedProperties.ps1 | PowerShell | mit | 24,287 |
$CommandName = $MyInvocation.MyCommand.Name.Replace(".Tests.ps1", "")
Write-Host -Object "Running $PSCommandPath" -ForegroundColor Cyan
. "$PSScriptRoot\constants.ps1"
Describe "$CommandName Unit Tests" -Tag 'UnitTests' {
Context "Validate parameters" {
[object[]]$params = (Get-Command $CommandName).Parame... | dsolodow/dbatools | tests/Repair-DbaServerName.Tests.ps1 | PowerShell | mit | 989 |
# halt immediately on any errors which occur in this module
$ErrorActionPreference = 'Stop'
function Invoke(
[string]
[Parameter(
Position=0,
Mandatory=$true,
ValueFromPipeline=$true,
ValueFromPipelineByPropertyName=$true)]
$ParametersJson
){
$Parameters = @{}
($P... | Appease/CreateAppeaseTaskTemplatePackage | Src/CreateAppeaseTaskTemplatePackage.psm1 | PowerShell | mit | 473 |
# ============Initialize environment============
. $PSScriptRoot\..\funcs.ps1
initEnv
# Get a hashtree with download links for each version
function pythonVersions() {
if (install_64bit){
$extension = "[-.]amd64"
} else {
$extension = ""
}
$url = "https://www.python.org/downloads/windo... | woutdenolf/wdncrunch | tools/windows/install-python.ps1 | PowerShell | mit | 3,420 |
data LocalizedData
{
# culture="en-US"
# TODO: Support WhatIf
ConvertFrom-StringData @'
InvalidIdentifyingNumber=The specified IdentifyingNumber ({0}) is not a valid Guid
InvalidPath=The specified Path ({0}) is not in a valid format. Valid formats are local paths, UNC, and HTTP
InvalidNameOrId=The specified... | KarolKaczmarek/xPSDesiredStateConfiguration | DSCResources/MSFT_xPackageResource/MSFT_xPackageResource.psm1 | PowerShell | mit | 44,567 |
$project = (Split-Path -Parent $MyInvocation.MyCommand.Path).Replace(".Tests", "")
$sut = (Split-Path -Leaf $MyInvocation.MyCommand.Path).Replace(".tests.", ".")
. "$project\$sut"
Describe "FunctionWithFileOperation" {
Context "Given the file exists, when the config is valid" {
Setup -File config.xml -Content ... | wulfland/PSVSTS | PSVSTS/MyPowerShellProject.Tests/FunctionWithFileOperation.tests.ps1 | PowerShell | mit | 936 |
function Test-OsVersion {
Get-WmiObject -Query 'Select Caption,Version from Win32_OperatingSystem' |
Select-Object Caption, Version, @{
Name = 'BuildVersion'
Expression = {
$PSVersiontable.BuildVersion
}
}, @{
Name = 'OSArchitecture'
Expression... | jaapbrasser/PowerShield | Internal/Get-OsVersion.ps1 | PowerShell | mit | 538 |
function Get-TargetResource
{
[CmdletBinding()]
[OutputType([System.Collections.Hashtable])]
param
(
[parameter(Mandatory = $true)] [System.String] $Name,
[parameter(Mandatory = $true)] [System.String] $ServiceAppName,
[parameter(Mandatory = $true)] [ValidateSet("SharePoin... | camiloborges/xSharePoint | Modules/SharePointDsc/DSCResources/MSFT_SPSearchContentSource/MSFT_SPSearchContentSource.psm1 | PowerShell | mit | 23,652 |
<#
This code is written and maintained by Darren R. Starr from Conscia Norway AS.
License :
Copyright (c) 2017 Conscia Norway AS
Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restric... | darrenstarr/cDayZeroDeploy | DSCResources/cUnattendXml/Classes/cUnattendXml.ps1 | PowerShell | mit | 11,968 |
#
# Module manifest for module 'PSDummy'
#
# Generated by: Erwan Quélin
#
# Generated on: 24/05/2016
#
@{
# Script module or binary module file associated with this manifest.
RootModule = 'PSDummy.psm1'
# Version number of this module.
ModuleVersion = '1.3.0'
# ID used to uniquely identify this module
GUID = '0e1a8... | equelin/PSDummy | PSDummy/PSDummy.psd1 | PowerShell | mit | 3,428 |
$packageName = 'produkey.portable'
$url = 'http://www.nirsoft.net/utils/produkey.zip'
$checksum = 'a2a62e27cbe0f70de6371a9ecd7149f7350a2b21'
$checksumType = 'sha1'
$url64 = 'http://www.nirsoft.net/utils/produkey-x64.zip'
$checksum64 = '93ee91ed9fb4c77477dff6eadc584ede3ffe168f'
$checksumType64 = 'sha1'
$toolsDir = "$(Sp... | dtgm/chocolatey-packages | automatic/_output/produkey.portable/1.83/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 935 |
# Copyright 2012 Aaron Jensen
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to ... | MattHubble/carbon | Test/Path/Test-TestUncPath.ps1 | PowerShell | apache-2.0 | 1,022 |
#==========================================================
# Edit the variable values below to configure how your .nupkg file is packed (i.e. created) and pushed (i.e. uploaded) to the NuGet gallery.
#
# If you have modified this script:
# - if you uninstall the "Create New NuGet Package From Project After Each Build... | PrintsCharming/ObjectHydrator | Foundation.ObjectHydrator/_CreateNewNuGetPackage/Config.ps1 | PowerShell | apache-2.0 | 4,441 |
function Remove-ProGetFeed
{
<#
.SYNOPSIS
Removes a feed from ProGet.
.DESCRIPTION
The `Remove-ProGetFeed` function removes a feed from ProGet. All packages in the feed are also deleted. Pass the session to the ProGet instance from which to delete the feed to the `Session` parameter (use t... | pshdo/ProGetAutomation | ProGetAutomation/Functions/Remove-ProGetFeed.ps1 | PowerShell | apache-2.0 | 2,946 |
#Explicitly import the module for testing
Import-Module 'ConnectReddit' -Verbose
$Global:TestsCompleted = @()
#This directory is used for Import/Export tests
$Global:TestExportsDirectory = $ENV:TEMP
$TestFolder = Join-Path -Path $PSScriptRoot -ChildPath 'Tests'
$TestScripts = Get-ChildItem -Path $TestFolder -Filter ... | markekraus/ConnectReddit | Test-Module.ps1 | PowerShell | apache-2.0 | 592 |
import-module au
$releases = 'https://storage.googleapis.com/downloads.webmproject.org/releases/webp/index.html'
function global:au_SearchReplace {
@{
".\tools\chocolateyInstall.ps1" = @{
"(?i)(^\s*packageName\s*=\s*)('.*')" = "`$1'$($Latest.PackageName)'"
}
".\tools\VERIFICA... | kkzinger/chocolatey-packages-new | automatic/webp/update.ps1 | PowerShell | apache-2.0 | 1,480 |
function New-VSSNSSubscription {
<#
.SYNOPSIS
Adds an AWS::SNS::Subscription resource to the template. The AWS::SNS::Subscription resource subscribes an endpoint to an Amazon Simple Notification Service (Amazon SNS topic. For a subscription to be created, the owner of the endpoint must confirm the subsc... | scrthq/Vaporshell | VaporShell/Public/Resource Types/New-VSSNSSubscription.ps1 | PowerShell | apache-2.0 | 23,048 |
function New-VSCognitoUserPoolGroup {
<#
.SYNOPSIS
Adds an AWS::Cognito::UserPoolGroup resource to the template. Specifies a new group in the identified user pool.
.DESCRIPTION
Adds an AWS::Cognito::UserPoolGroup resource to the template. Specifies a new group in the identified user pool.
... | scrthq/Vaporshell | VaporShell/Public/Resource Types/New-VSCognitoUserPoolGroup.ps1 | PowerShell | apache-2.0 | 15,475 |
function Add-VSGroundStationDataflowEndpointGroupEndpointDetails {
<#
.SYNOPSIS
Adds an AWS::GroundStation::DataflowEndpointGroup.EndpointDetails resource property to the template. The security details and endpoint information.
.DESCRIPTION
Adds an AWS::GroundStation::DataflowEndpointGroup.... | scrthq/Vaporshell | VaporShell/Public/Resource Property Types/Add-VSGroundStationDataflowEndpointGroupEndpointDetails.ps1 | PowerShell | apache-2.0 | 2,381 |
$JNLPPort=57816
$ServerName="dotnet-ci"
echo "Adding jenkins Master $ServerName port Jenkins JNLP port ($JNLPPort) to have a 30 minute timeout."
Get-AzureVM -ServiceName "dotnet-ci" -Name $ServerName | Add-AzureEndpoint -Name "Jenkins" -Protocol "tcp" -PublicPort $JNLPPort -LocalPort $JNLPPort -IdleTimeoutInMinutes 3... | modulexcite/dotnet-ci | ci-nodes/management/Setup-Azure-IdleTimeout.ps1 | PowerShell | mit | 338 |
<#
.NOTES
Copyright (c) Microsoft Corporation. All rights reserved.
Use of this sample source code is subject to the terms of the Microsoft
license agreement under which you licensed this sample source code. If
you did not accept the terms of the license agreement, you are n... | mebersol/Virtualization-Documentation | windows-server-container-tools/DockerTLS/DockerCertificateTools.ps1 | PowerShell | mit | 13,607 |
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.
Describe "Resolve-Path returns proper path" -Tag "CI" {
BeforeAll {
$driveName = "RvpaTest"
$root = Join-Path $TestDrive "fakeroot"
$file = Join-Path $root "file.txt"
$null = New-Item -Path ... | Cowmonaut/PowerShell | test/powershell/Modules/Microsoft.PowerShell.Management/Resolve-Path.Tests.ps1 | PowerShell | mit | 2,170 |
param($installPath, $toolsPath, $package, $project)
# set dll to copy to build dir
$wkdll = $project.ProjectItems.Item("wkhtmltox0.dll")
$copyToOutput = $wkdll.Properties.Item("CopyToOutputDirectory")
$copyToOutput.Value = 1
# and each of the dependencies
$dep1 = $project.ProjectItems.Item("libeay32.dll")
$dep2 = $p... | apugliese1990/TO.BerichtDokuManager | packages/Pechkin.0.5.8.1/tools/net40/install.ps1 | PowerShell | mit | 825 |
function Get-DbaDbRole {
<#
.SYNOPSIS
Get the database roles for each instance(s) of SQL Server.
.DESCRIPTION
The Get-DbaDbRole returns connected SMO object for database roles for each instance(s) of SQL Server.
.PARAMETER SqlInstance
The target SQL Server instance or instances... | kozloski/dbatools | functions/Get-DbaDbRole.ps1 | PowerShell | mit | 5,324 |
# Copyright 2019 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to ... | jackfrancis/kubernetes | cluster/gce/windows/configure.ps1 | PowerShell | apache-2.0 | 7,217 |
param([string]$env_file='.env', [string]$out_file='out\build.zip', [switch]$v, [switch]$skip_install)
Write-Output "$(Get-Date) [START] build"
# check if out folder exists
If (!(Test-Path out)) {
Write-Output "$(Get-Date) [START] Creating output directory (out)"
# create out folder
mkdir out | out-null
Write-Outp... | yi-jiayu/bus-eta-bot-sg | build.ps1 | PowerShell | mit | 2,780 |
# -----------------------------------------------------------------------
# Copyright : GSoft @2014
# Model : Cross Site Publishing CMS
# File : Setup-Control.template.ps1
# Description : Add the control containing the Google Id Tracker in the additional page head
# ---------------------------------------... | GSoft-SharePoint/Dynamite-Components | Source/GSoft.Dynamite.Models.CrossSitePublishingCMS/Modules/Search/SRCH_02/Setup-Control.template.ps1 | PowerShell | mit | 746 |
param
(
[Parameter(Mandatory = $true)]
[System.String]
$ConfigurationName
)
Configuration $ConfigurationName
{
param
(
[Parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[System.String]
$GroupName,
[ValidateSet('Present', 'Absent')]
[ValidateN... | PowerShell/xPSDesiredStateConfiguration | tests/Integration/DSC_xGroupResource_MembersToIncludeExclude.config.ps1 | PowerShell | mit | 761 |
$DSCResourceName = 'MSFT_xDNSServerAddress'
$DSCModuleName = 'xNetworking'
$Splat = @{
Path = $PSScriptRoot
ChildPath = "..\..\DSCResources\$DSCResourceName\$DSCResourceName.psm1"
Resolve = $true
ErrorAction = 'Stop'
}
$DSCResourceModuleFile = Get-Item -Path (Join-Path @Splat)
$moduleRoot = "${env:... | rsWinAutomationSupport/xNetworking | Tests/Unit/MSFT_xDNSServerAddress.Tests.ps1 | PowerShell | mit | 24,172 |
[cmdletbinding(SupportsShouldProcess=$true)]
param($publishProperties=@{}, $packOutput, $pubProfilePath)
# to learn more about this file visit https://go.microsoft.com/fwlink/?LinkId=524327
try{
if ($publishProperties['ProjectGuid'] -eq $null){
$publishProperties['ProjectGuid'] = '963bd2d9-640b-4d... | zhangsiy/AspNetCoreBoilerPlate | src/MyWebService/Properties/PublishProfiles/CcBrowserPublishProfile-publish.ps1 | PowerShell | mit | 792 |
[CmdletBinding()]
[Diagnostics.CodeAnalysis.SuppressMessageAttribute("PSAvoidUsingConvertToSecureStringWithPlainText", "")]
param(
[Parameter()]
[string]
$SharePointCmdletModule = (Join-Path -Path $PSScriptRoot `
-ChildPath "..\Stubs\SharePoint\15.0.4805.1000\Microso... | MikeLacher448/xSharePoint | Tests/Unit/SharePointDsc/SharePointDsc.SPUserProfileSyncConnection.Tests.ps1 | PowerShell | mit | 48,198 |
<#
.Synopsis
Use this Cmdlet to update the log of a Zenoss Event
.DESCRIPTION
Long description
.EXAMPLE
Update-ZenossEventLog -evid 005056a5-7c3e-9c9c-11e5-fcd8cbbdb0f1 -message "Updated with PowerShell!"
Operation was a True
>Updates an event with new log text
.EXAMPLE
Update-ZenossEventLog -ev... | 1RedOne/PSZenoss | Public/Update-ZenossEventLog.ps1 | PowerShell | mit | 2,404 |
param
(
[Parameter(Mandatory = $true)]
[System.String]
$ConfigurationName
)
Configuration $ConfigurationName
{
param
(
[Parameter(Mandatory = $true)]
[ValidateNotNullOrEmpty()]
[System.String]
$Path,
[Parameter(Mandatory = $true)]
[AllowEmptyString()... | PowerShell/xPSDesiredStateConfiguration | tests/Integration/DSC_xWindowsProcessWithCredential.config.ps1 | PowerShell | mit | 941 |
########################################################################
#
# Linux on Hyper-V and Azure Test Code, ver. 1.0.0
# Copyright (c) Microsoft Corporation
#
# All rights reserved.
# Licensed under the Apache License, Version 2.0 (the ""License"");
# you may not use this file except in compliance with the Licen... | bogdancarpusor/lis-test | WS2012R2/lisa/setupscripts/FCOPY_disableEnable.ps1 | PowerShell | apache-2.0 | 14,377 |
#
# Module manifest for module 'PSGet_Azure'
#
# Generated by: Microsoft Corporation
#
# Generated on: 6/4/2017
#
@{
# Script module or binary module file associated with this manifest.
# RootModule = ''
# Version number of this module.
ModuleVersion = '4.1.0'
# Supported PSEditions
# CompatiblePSEditions = @()
# ... | atpham256/azure-powershell | src/ServiceManagement/Services/Commands.Utilities/Azure.psd1 | PowerShell | apache-2.0 | 35,560 |
$ErrorActionPreference = 'Stop'
import-module au
$url = 'https://desktop.line-scdn.net/win/new/LineInst.exe'
function global:au_SearchReplace {
@{
'tools\ChocolateyInstall.ps1' = @{
"(^[$]checksum\s*=\s*)('.*')" = "`$1'$($Latest.Checksum32)'"
}
}
}
function global:au_GetLatest... | mikecole/chocolatey-packages | automatic/line/update.ps1 | PowerShell | apache-2.0 | 574 |
param($hostname,$datafname,$outfname,$firstblock,$lastblock,$nchans,$mintemp,$maxtemp)
if (!$hostname) {
echo "hostname is necessary"
}
else {
netsh advfirewall firewall add rule name=ZMQMapReduce dir=in action=allow protocol=TCP localport=5000
$cmd="C:\Titanic\Clusterer\TitanSpikeClusterer.exe"
$prc="C:\Titan... | Olveczky-Lab/FAST | Releases/1.0/MasterNode/StartClustering.ps1 | PowerShell | bsd-3-clause | 1,107 |
param($installPath, $toolsPath, $package, $project)
if (Get-Service | ?{ $_.Name -eq 'MSSQL$SQLEXPRESS' -and $_.Status -eq 'Running' })
{
Add-EFDefaultConnectionFactory $project 'System.Data.Entity.Infrastructure.SqlConnectionFactory, EntityFramework'
}
else
{
$localDbVersion = Get-ChildItem 'HKLM:\SOFTWARE\M... | Knoema/Localization | packages/EntityFramework.6.4.0/tools/install.ps1 | PowerShell | mit | 14,091 |
$packageName = '{{PackageName}}'
$installerType = 'exe'
$silentArgs = '/S'
$url = '{{DownloadUrl}}'
$checksum = '{{Checksum}}'
$checksumType = 'md5'
$url64 = '{{DownloadUrlx64}}'
$checksum64 = '{{Checksumx64}}'
$checksumType64 = 'md5'
$validExitCodes = @(0)
Install-ChocolateyPackage -PackageName "$packageName" `
... | maharishi/chocolatey-packages | automatic/sqlitebrowser/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 792 |
properties {
$BaseDirectory = Resolve-Path ..
$ProjectName = "Piercer"
$NugetOutputDir = "$BaseDirectory\Artifacts"
$SrcDir = "$BaseDirectory\Src"
$ReportsDir = "$BaseDirectory\Artifacts"
$SolutionFilePath = "$BaseDirectory\$ProjectName.sln"
$AssemblyInfoFilePath = "$SrcDir\Piercer.Middleware\P... | dennisdoomen/piercer | Build/default.ps1 | PowerShell | apache-2.0 | 5,595 |
$packageName = 'telegram.portable'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url = 'https://updates.tdesktop.com/tsetup/tportable.0.9.2.zip'
$checksum = '8a84a7eb7bccb6df877fe57c0d6a7a248589054d'
$checksumType = 'sha1'
Install-ChocolateyZipPackage -PackageName "$packageName" `
... | dtgm/chocolatey-packages | automatic/_output/telegram.portable/0.9.2/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 565 |
function Get-TargetResource
{
[CmdletBinding()]
[OutputType([System.Collections.Hashtable])]
param
(
[Parameter(Mandatory = $true)]
[System.String]
$WebAppUrl,
[Parameter()]
[Microsoft.Management.Infrastructure.CimInstance[]]
$Members,
[Parameter... | puppetlabs/puppetlabs-dsc | lib/puppet_x/dsc_resources/SharePointDsc/DSCResources/MSFT_SPWebAppPolicy/MSFT_SPWebAppPolicy.psm1 | PowerShell | apache-2.0 | 29,628 |
[CmdletBinding()]
param($IncludeStream, [switch] $Force)
Import-Module AU
$releases = 'https://github.com/kubernetes/kubernetes/releases/latest'
function global:au_BeforeUpdate { Get-RemoteFiles -Purge -NoSuffix }
function global:au_SearchReplace {
@{
".\legal\VERIFICATION.txt" = @{
"(?i)(^\s*location o... | jberezanski/chocolatey-coreteampackages | automatic/kubernetes-cli/update.ps1 | PowerShell | apache-2.0 | 1,583 |
# ----------------------------------------------------------------------------------
#
# Copyright Microsoft Corporation
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org... | atpham256/azure-powershell | src/ServiceManagement/StorSimple/Commands.StorSimple.Test/ScenarioTests/BackupPolicyTests.ps1 | PowerShell | apache-2.0 | 2,668 |
function Out-XmlSection
{
<#
.SYNOPSIS
Output formatted Xml section.
#>
[CmdletBinding()]
param
(
## PScribo document section
[Parameter(Mandatory, ValueFromPipeline)]
[System.Management.Automation.PSObject] $Section
)
process
{
$sectionId = ($Section.... | iainbrighton/PScribo | Src/Plugins/Xml/Out-XmlSection.ps1 | PowerShell | mit | 2,176 |
#Requires -Version 7.0
param(
[string]$filter,
[switch]$clean,
[switch]$vet,
[switch]$generateExample,
[switch]$generateMockTest,
[switch]$skipBuild,
[switch]$cleanGenerated,
[switch]$format,
[switch]$tidy,
[string]$config = "autorest.md",
[string]$autorestVersion = "3.7.3",
... | Azure/azure-sdk-for-go | eng/scripts/Invoke-MgmtTestgen.ps1 | PowerShell | mit | 889 |
###Exposed Functions
function Get-EsIndexes() {
[CmdletBinding()]
Param (
[ValidateSet("http","https")]
[string]$Protocol = "http",
[string]$Server = "localhost",
[int]$Port = 9200,
[string]$IndexPrefix = "*"
)
Begin {
$indexes = Invoke-RestMethod -Method... | onyxhat/elasticsearch-maintenance | ES-Maintenance.psm1 | PowerShell | mit | 8,570 |
######################################################################################################
#
# Script: Unix_Capacity_Projection_Report.ps1
#
# Author: Martin Sustaric
#
# Date: 14/07/2014
#
#
# About: This script extracts the list of Unix servers that are monitored buy the
# SCOM Gateway Server (Usi... | Buzzcola81/scom2012forecasting | Unix_Capacity_Projection_Report.ps1 | PowerShell | mit | 21,242 |
Describe 'Fake tests' {
Context 'Fake test case' {
}
} | MathieuBuisson/PSCodeHealth | Tests/TestData/FakeTestFile.ps1 | PowerShell | mit | 72 |
# Load the Helper Module
Import-Module -Name "$PSScriptRoot\..\Helper.psm1"
# Localized messages
data LocalizedData
{
# culture="en-US"
ConvertFrom-StringData -StringData @'
NoWebAdministrationModule = Please ensure that WebAdministration module is installed.
AddingType = Adding ... | devrandorfer/ScorchDev | PowerShellModules/xWebAdministration/1.12.0.0/DSCResources/MSFT_xIisMimeTypeMapping/MSFT_xIisMimeTypeMapping.psm1 | PowerShell | mit | 5,388 |
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.
Describe 'Argument transformation attribute on optional argument with explicit $null' -Tags "CI" {
$tdefinition = @'
using System;
using System.Management.Automation;
using System.Reflection;
namespace MS... | Cowmonaut/PowerShell | test/powershell/Language/Parser/ParameterBinding.Tests.ps1 | PowerShell | mit | 17,990 |
# Copyright (c) 2016 Microsoft Corporation. All Rights Reserved.
# Licensed under the MIT License (MIT)
Describe "Get-RsItemReference" {
Context "Get-RsItemReference with min parameters"{
$folderName = 'SutGetRsItemReference_MinParameters' + [guid]::NewGuid()
New-RsFolder -Path... | warren2600/ReportingServicesTools | Tests/CatalogItems/Get-RsItemReference.Tests.ps1 | PowerShell | mit | 4,939 |
#region Info
<#
#################################################
# modified by : Joerg Hochwald
# last modified : 2016-04-03
#################################################
Support: https://github.com/jhochwald/NETX/issues
#>
#endregion Info
#region License
<#
Copyright (c) 2012-2016, NET-Experts <... | jhochwald/MyPowerShellStuff | Profile/functions/Invoke-RemoteScript.ps1 | PowerShell | mit | 16,651 |
<#
.SYNOPSIS
Will create a new registry key if it doesn't exist
.PARAMETER Path
Path of the key
.PARAMETER Name
Name of the key
.PARAMETER Type
Type of the key. Possible values are: String, Binary, DWord, ExpandString, MultiString, QWord
.PARAMETER Value
Value of key
.EXAMPLE
C:\PS> Set-My... | ansarada/PSAX | Functions/Set-MyItemProperty.ps1 | PowerShell | mit | 1,872 |
# Extract project info from SharedAssemblyInfo.cs
get-content ..\SharedAssemblyInfo.cs |
foreach {
if ($_ -match "Company\(`"(?<content>.*)`"\)") { $company = $matches['content'] }
if ($_ -match "Copyright\(`"(?<content>.*)`"\)") { $copyright = $matches['content'] }
if ($_ -match "Description\(... | FXGuild/CommonCSharp | NuGet/UploadToNuGetGallery.ps1 | PowerShell | mit | 1,847 |
# Logging
Start-Transcript -Path C:\MigrateLogs.txt -Force -NoClobber -Append | Out-Null
# Get domain credentials. Customize `-Username $CUser` to match your environment if you
# have a specific naming scheme for domain admin accounts vs regular users
$Creds = $null
# Set $CUser to the currently logged-on user
$CUse... | MSD40IT/stable-pwsh | Out-dated/MigrateUserData-v1.ps1 | PowerShell | mit | 6,255 |
$packageName = 'firefox-nightly'
$softwareVersion = '55.0.1.2017033011-alpha' -Replace "^(\d+)\.(\d+)\.(\d+)[^-]+-([a-z]).*",'$1.$2$4$3'
$softwareName = "Nightly $softwareVersion*"
$installerType = 'exe'
$silentArgs = '/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-'
$validExitCodes = @(0)
[array]$key = Get-UninstallRe... | dtgm/chocolatey-packages | automatic/_output/firefox-nightly/55.0.1.2017033011/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 820 |
$packageName = '{{PackageName}}'
$packageSearch = "Telegram Desktop*"
$installerType = 'exe'
$silentArgs = '/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-'
$validExitCodes = @(0)
Get-ItemProperty -Path @( 'HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
'HKLM:\Software... | maharishi/chocolatey-packages | automatic/telegram.install/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 955 |
# ************************************************************************
# *
# * Copyright 2016 OSIsoft, LLC
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
# * You may obtain a copy of the License at
# *
# * <http://www.apac... | jdryden-osi/PI-Security-Audit-Tools | PISecurityAuditDSC/ResourceDesign.ps1 | PowerShell | apache-2.0 | 6,518 |
param
(
[Parameter(Mandatory)][string]$RoleName,
[Parameter(Mandatory)][pscredential]$cred,
[Parameter(Mandatory)][string]$OutputPath
)
$ConfigData = @{
AllNodes = @(
@{
NodeName = "CertificateAuthority";
PSDscAllowPlainTextPassword = $true;
PSDscAllowDomainUser = $true;
... | olljanat/Lab-DSC-configs | Roles/CertificateAuthority.ps1 | PowerShell | apache-2.0 | 1,356 |
Set-ExecutionPolicy ByPass
iex ((new-object net.webclient).DownloadString('https://chocolatey.org/install.ps1'))
choco install WindowsAzurePowershell
choco install googlechrome
choco install putty
choco install git
choco install nodejs.install
choco install notepadplusplus.install
choco install fiddler
choco install wg... | gartdan/Azure-CustomScriptExtensions | Install-DevTools-VSAlreadyInstalled.ps1 | PowerShell | apache-2.0 | 436 |
@{
ModuleVersion = '2.0.0'
GUID = '518a1b88-8091-419f-8404-a5662d495173'
Author = 'Dave Wyatt'
CompanyName = 'DevOpsGuys'
Copyright = 'Copyright 2015, DevOpsGuys'
Description = 'DSC resources for managing Octopus Deploy'
}
| dlwyatt/WinOps2015Demo | DSC_Resources/DOG_OctopusDeployResources/DOG_OctopusDeployResources.psd1 | PowerShell | apache-2.0 | 272 |
. ..\New-PSItem.ps1
rm *.xlsx
$(
New-PSItem 12001 Nails 37 3.99 =C2*D2 (echo ID Product Quantity Price Total)
New-PSItem 12002 Hammer 5 12.10 =C3*D3
New-PSItem 12003 Saw 12 15.37 =C4*D4
New-PSItem 12010 Drill 20 8 =C5*D5
New-PSItem 12011 Crowbar 7 23.48 =C6*D6
) | Export-Excel funct... | mrpullen/ImportExcel | Examples/SpreadsheetCells/CalculatedFields.ps1 | PowerShell | apache-2.0 | 346 |
$packageName = 'firefox-nightly'
$softwareVersion = '58.0.1.2017102914-alpha' -Replace "^(\d+)\.(\d+)\.(\d+)[^-]+-([a-z]).*",'$1.$2$4$3'
$softwareName = "Nightly $softwareVersion*"
$installerType = 'exe'
$silentArgs = '/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-'
$validExitCodes = @(0)
[array]$key = Get-UninstallReg... | dtgm/chocolatey-packages | automatic/_output/firefox-nightly/58.0.1.2017102914/tools/chocolateyUninstall.ps1 | PowerShell | apache-2.0 | 817 |
function Get-TargetResource
{
[CmdletBinding()]
[OutputType([System.Collections.Hashtable])]
param
(
[parameter(Mandatory = $true)] [System.String] $SiteUrl,
[parameter(Mandatory = $false)] [System.Management.Automation.PSCredential] $InstallAccount
)
Write-Verbose -Message "G... | BrianFarnhill/SharePointDsc | Modules/SharePointDsc/DSCResources/MSFT_SPAppCatalog/MSFT_SPAppCatalog.psm1 | PowerShell | mit | 2,239 |
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
param(
# Skips a check that prevents building PowerShell on unsupported Linux distributions
[parameter(Mandatory = $false)][switch]$SkipLinuxDistroCheck = $false
)
Set-StrictMode -Version 3.0
# On Unix paths is separated by colon
# On W... | daxian-dbw/PowerShell | build.psm1 | PowerShell | mit | 122,590 |
<#
This script attempts to remove a resource group by first removing all the things that prevent removing resource groups
- Locks, backup protection, geo-pairing, etc.
It is a living script as we keep finding more cases... if you find one please add it.
#>
param(
[string][Parameter(mandatory = $true)] $Resource... | neudesic/azure-quickstart-templates | test/ci-scripts/Kill-AzResourceGroup.ps1 | PowerShell | mit | 16,869 |
$packageName = 'sumo'
$installerType = 'exe'
$silentArgs = '/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-'
$url = 'http://www.kcsoftwares.com/files/sumo_lite.exe'
$checksum = '3ce10dcb0afb9876fc7b4472bd946e159b853fde'
$checksumType = 'sha1'
$validExitCodes = @(0)
$scriptPath = $(Split-Path -parent $MyInvocation.MyComma... | dtgm/chocolatey-packages | automatic/_output/sumo/4.1.0.279/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 822 |
$packageName = 'dolphin'
$url = 'http://dl.dolphin-emu.org/builds/dolphin-master-4.0-8157-x64.7z'
$checksum = '69b5e4d56e373c5db584b9be06883f053217d444'
$checksumType = 'sha1'
$url64 = $url
$checksum64 = $checksum
$checksumType64 = $checksumType
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
In... | dtgm/chocolatey-packages | automatic/_output/dolphin/4.0.8157/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 761 |
$packageName = 'telegram.portable'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url = 'https://updates.tdesktop.com/tsetup/tportable.0.8.52.zip'
$checksum = '3b476c17d08cc09b6b7258844b3817af4e9a5c64'
$checksumType = 'sha1'
Install-ChocolateyZipPackage -PackageName "$packageName" `
... | dtgm/chocolatey-packages | automatic/_output/telegram.portable/0.8.52/tools/chocolateyInstall.ps1 | PowerShell | apache-2.0 | 566 |
$frameworkPath = (Get-ItemProperty "HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v4\Client").InstallPath
set-alias regIIS $frameworkPath\aspnet_regiis.exe
function TestInclude ([string]$name) {
(get-host).ui.rawui.foregroundcolor= "Magenta"
$name
(get-host).ui.rawui.foregroundcolor= "Yellow"
}
function CheckI... | andrew-armitage-15below/Ensconce | createiis6app.ps1 | PowerShell | mit | 10,714 |
function EnsureLookupField($fieldName, $fieldDisplayName, $targetList, $lookupList) {
$field = $null
$field = Get-PnPField -List $targetList -Identity $fieldName -ErrorAction SilentlyContinue
if ($field -eq $null) {
$guid = [System.Guid]::NewGuid().ToString("B")
$xml = "<Field Type='Lookup' ... | AJIXuMuK/sp-dev-fx-webparts | samples/react-sitepages-metadata/install/configure-lists.ps1 | PowerShell | mit | 1,879 |
[CmdletBinding()]
param()
# Arrange.
. $PSScriptRoot/../../lib/Initialize-Test.ps1
Microsoft.PowerShell.Core\Import-Module Microsoft.PowerShell.Security
$module = Microsoft.PowerShell.Core\Import-Module $PSScriptRoot/../../../Tasks/AzurePowerShell/ps_modules/VstsAzureHelpers_ -PassThru
$endpoint = @{
Auth = @{
... | AArnott/vso-agent-tasks | Tests/L0/Common-VstsAzureHelpers_/Initialize-AzureSubscription.PassesValuesWhenSPAuth.ps1 | PowerShell | mit | 3,236 |
Param($DomainFullName,$DPMPName,$Role,$ProvisionToolPath)
$logpath = $ProvisionToolPath+"\InstallMPlog.txt"
$ConfigurationFile = Join-Path -Path $ProvisionToolPath -ChildPath "$Role.json"
$Configuration = Get-Content -Path $ConfigurationFile | ConvertFrom-Json
#Install MP
$Configuration.InstallMP.Status = 'Running'
$... | neudesic/azure-quickstart-templates | application-workloads/sccm/sccm-technicalpreview/DSC/InstallMP.ps1 | PowerShell | mit | 4,208 |
$module = 'Dramatic.Asaph'
$gitrepository = 'https://github.com/victorvogelpoel/Dramatic.Asaph'
# Make sure the module is not loaded
Remove-Module $module -ErrorAction SilentlyContinue
# Download latest version
$webclient = New-Object System.Net.WebClient
$url = "$gitrepository/archive/master.zip"
Write-... | victorvogelpoel/Dramatic.Asaph | install/install.ps1 | PowerShell | mit | 1,359 |
$version=$(select-string -Path Dockerfile -Pattern "ENV DOCKER_VERSION").ToString().split()[-1]
docker tag docker-cli stefanscherer/docker-cli-windows:$version-1607-deprecated
docker push stefanscherer/docker-cli-windows:$version-1607-deprecated
npm install -g rebase-docker-image
rebase-docker-image `
stefanscherer... | StefanScherer/dockerfiles-windows | docker-cli/push.ps1 | PowerShell | mit | 1,561 |
Function Select-GUI
{
<#
.SYNOPSIS
Open or save files or open folders using Windows forms.
.PARAMETER Start
The start directory for the form.
.PARAMETER Description
Text that is included on the chrome of the form.
.PARAMETER Ext
Adds an extension filter to file open or save forms.
.PARAMETER Fil... | gbuktenica/Select-GUI | Select-GUI.ps1 | PowerShell | mit | 3,901 |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.